#!/bin/sh
#
# source location: ftp.gnome.org/pub/gnome/sources/gnome-cups-manager/0.33/gnome-cups-manager-0.33.tar.bz2
#
# packager : gmg (gerard.monpontet@orange.fr)
#

#------------------Set Some Variables

buildir=$(pwd)
soft="gnome-cups-manager"
softversion="0.33"
packageversion="54.1"
arch="i486"
cpu="i686"
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --disable-static \
    --enable-shared

make -j2
make install DESTDIR=$dest

rm -f $dest/usr/share/applications/gnome-cups-manager.desktop

mkdir -p $dest/usr/share/applications
cat <<"EOF" > $dest/usr/share/applications/gnome-cups-manager.desktop
[Desktop Entry]
Name=Printing
Name[ar]=طباعة
Name[be@latin]=Druk
Name[ca]=Impressió
Name[cs]=Tisk
Name[da]=Udskriver
Name[dz]=དཔར་བསྐྲུན་འབད་དོ།
Name[el]=Εκτυπώσεις
Name[en_GB]=Printing
Name[es]=Impresión
Name[eu]=Inprimatzea
Name[fi]=Tulostus
Name[fr]=Impression
Name[gl]=Imprimindo
Name[he]=מדפיס
Name[hu]=Nyomtatás
Name[it]=Stampa
Name[ko]=인쇄
Name[lt]=Spausdinimas
Name[lv]=Notiek drukāšana
Name[nb]=Skrivere
Name[ne]=मुद्रण गर्दै
Name[nl]=Printen
Name[oc]=Estampatge
Name[pl]=Drukowanie
Name[pt]=Impressão
Name[pt_BR]=Impressão
Name[sv]=Utskrift
Name[zh_HK]=打印
Name[zh_TW]=列印
Comment=Configure your printers
Comment[be@latin]=Kanfihuruj svaje drukarki
Comment[ca]=Configureu impressores
Comment[cs]=Nastavit vaše tiskárny
Comment[da]=Konfigurér dine printere
Comment[dz]=ཁྱོད་རང་གི་དཔར་འཕྲུལ་ཚུ་རིམ་སྒྲིག་འབད།
Comment[el]=Ρύθμιση των εκτυπωτών σας
Comment[en_GB]=Configure your printers
Comment[es]=Configure sus impresoras
Comment[eu]=Konfiguratu inprimagailuak
Comment[fi]=Määrittele tulostimet
Comment[fr]=Configure vos imprimantes
Comment[gl]=Configurar as súas impresoras
Comment[he]=בגדר את המדפסות שלך
Comment[hu]=Nyomtatók beállítása
Comment[it]=Per configurare le proprie stampanti
Comment[ko]=프린터를 설정합니다
Comment[lt]=Konfigūruoti jūsų spausdintuvus
Comment[lv]=Konfigurēt jūsu printerus
Comment[nb]=Konfigurer dine skrivere
Comment[ne]=तपाईँको मुद्रक कन्फिगर गर्नुहोस्
Comment[nl]=Uw printers instellen
Comment[oc]=Configurar vòstras estampairas
Comment[pl]=Konfiguracja drukarek
Comment[pt]=Configure as suas impressoras
Comment[pt_BR]=Configure suas impressoras
Comment[sv]=Konfigurera dina skrivare
Comment[zh_HK]=設定你的打印機
Comment[zh_TW]=設定您的印表機
Exec=gksu gnome-cups-manager
Icon=gnome-dev-printer
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;Application;Settings;System;HardwareSettings;
X-GNOME-Bugzilla-Bugzilla=GNOME
X-GNOME-Bugzilla-Product=gnome-print
X-GNOME-Bugzilla-Component=gnome-cups-manager
X-GNOME-Bugzilla-Version=0.33
EOF

mkdir -p $dest/install

#------------------ make a slack-desc file

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

                  |-----handy-ruler-----------------------------------------------|
gnome-cups-manager: gnome-cups-manager (gnome gui interface for cups)
gnome-cups-manager:
gnome-cups-manager: gnome-cups-manager is gnome graphic manager interface for cups
gnome-cups-manager:
gnome-cups-manager:
gnome-cups-manager:
gnome-cups-manager:
gnome-cups-manager:
gnome-cups-manager:
gnome-cups-manager:
gnome-cups-manager:
EODESC

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a ChangeLog COPYING INSTALL NEWS README \
$dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/share/systemtools/applications
cp $dest/usr/share/applications/gnome-cups-manager.desktop $dest/usr/share/systemtools/applications

rm -r $dest/usr/share/$soft/xd2-testpage*
cp -a $buildir/xd2-testpage* $dest/usr/share/$soft/

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5